@@ -2,6 +2,7 @@
 from subprocess import call, TimeoutExpired, Popen
 import urllib.request
 import os
+from os.path import dirname
 import glob
 import shutil
 import argparse
@@ -47,12 +48,18 @@ def jar2java(jar, dir):
     
     executor = ThreadPoolExecutor(max_workers=8)
     
-    for path in Path(path_jar).rglob('*.class'):
+    owd = os.getcwd()
+    os.chdir(path_jar)
+    for path in Path('.').rglob('*.class'):
         if "$" in path.name:
             continue
-        filename = os.path.join(*(dir.split('/') + list(path.with_suffix('.java').parts[4:])))
+        filename = "../../src/" + str(path.with_suffix('.java'))
+        #print(filename)
         Path(os.path.dirname(filename)).mkdir(parents=True, exist_ok=True)
         executor.submit(Class2Java, filename, package_path, path)
+    executor.shutdown(wait=True)
+    os.chdir(owd)
+    return 0
 
 def Class2Java(filename, package_path, path):
     file = open(filename, "w")
@@ -73,14 +80,14 @@ def Class2Java(filename, package_path, path):
 def decompile(apk, dir):
     package_path = os.path.dirname(os.path.realpath(__file__))
     if not os.path.exists(dir):
-        os.mkdir(dir)
-    basename = os.path.basename(apk)
-    call(["apktool", "-f", "d", apk, "-o", "%s/%s" % (dir, basename)])
-    call(["unzip", apk, "-d", "%s/%s/zip" % (dir, basename)])
+        Path(dir).mkdir(parents=True, exist_ok=True)
+    #basename = os.path.basename(apk)
+    call(["apktool", "-f", "d", apk, "-o", "%s/apktools/" % (dir)])
+    call(["unzip", apk, "-d", "%s/zip" % (dir)])
     call([glob.glob(package_path + "/tools/dex-tools/*/d2j-dex2jar.sh")[0],
-        "%s/%s/zip/classes.dex"\
-        % (dir, basename), "-o", "%s/%s/zip/apk.jar" % (dir, basename)])
-    jar2java("%s/%s/zip/apk.jar" % (dir, basename), "%s/%s/src/" % (dir, basename))
+        "%s/zip/classes.dex"\
+        % (dir), "-o", "%s/zip/apk.jar" % (dir)])
+    return jar2java("%s/zip/apk.jar" % (dir), "%s/src/" % (dir))
     #try:
     #    p = Popen(["java", "-jar", package_path + "/tools/jd-cli/jd-cli.jar", "-od", "%s/%s/src/" % (dir, basename) ,"-sr",
     #    "%s/%s/zip/apk.jar" % (dir, basename)], shell=False) 
